Trait i2cdev::sensors::Barometer
[−]
[src]
pub trait Barometer {
fn pressure_kpa(&mut self) -> I2CResult<f32>;
}Trait for sensors that provide access to pressure readings
Required Methods
fn pressure_kpa(&mut self) -> I2CResult<f32>
Get a pressure reading from the sensor in kPa
Returns Some(temperature) if avialable, otherwise returns None
Implementors
impl<T> Barometer for MPL115A2BarometerThermometer<T> where T: I2CDevice + Sized